#!/usr/bin/perl
=help

CONKY WEATHER SCRIPT v2.1

USAGE:

	perl weather.pl code language units template output

PARAMETERS:

code	

	The weather.com city code.
	See http://xoap.weather.com/search/search?where=%s where %s stands for your location.

	The codes for most of the Czech and Slovak locations are available at the end of this file.
	For these locations, you can use even the name as written in the first column.

language

	"EN" for English, "CZ" for Czech, "SK" for Slovak. (The parameter is case-insensitive.)

units

	System of units: "s" for standard aka imperial, "m" for metric. (The parameter is case-insensitive.)

template

	A textfile with the template. The format is identical with the Conky format, but these new variables
	are available:
		__________________________________________________________________________________________________
		Variables without arguments

			wBarTendency, wBarTendencySymbol, wCode, wConditions, wConditionsSymbol, wCountry,
			wDewPoint,wWindSpeed, wFlik, wHumidity, wLatitude, wLocation, wLongitude, wMoon,
			wMoonSymbol, wObservation, wObservationCountry, wPressure, wSunrise, wSunset, wSuplDate,
			wSuplTime, wTemperature, wUnitDistance, wUnitLatitude, wUnitLongitude, wUnitPressure,
			wUnitSpeed, wUnitTemperature, wUpdateTime, wUVIndex, wUVLevel, wVisibility, wWindAzimuth, 
			wWindDirection, wZone

		EXAMPLE: $wCode or ${wCode }
		__________________________________________________________________________________________________
		Variables with one numeric argument standing for the number of the day starting with "0" for today

			wDayDate, wDayHighestTemperature, wDayLowestTemperature, wDayMonth, wDayName_Short,
			wDayName, wDaySunrise, wDaySunset

		EXAMPLE: ${wDayHighestTemperature 8}
		__________________________________________________________________________________________________
		Variables with two numeric arguments, the first standing for the number of the day starting with "0"
		for today and the latter for the day part, "0" for day and "1" for night.

			wDayPartConditions, wDayPartConditions_Long, wDayPartConditions_Short, wDayPartHumidity,
			wDayPartPrecipitation, wDayPartConditionsSymbol, wDayPartWindAzimuth, wDayPartWindDirection,
			wDayPartWindSpeed

		EXAMPLE: ${wDayPartWindSpeed 3  0}
		__________________________________________________________________________________________________
		Variable "wString" with one string argument. It returns the translation of this string as given
		in the string table starting at the line 444 of this file. You can add your own strings, but the
		string in the table should be lower-case. Use "_" instead of spaces.

		This variable is usable for multilingual templates.

		EXAMPLE: ${ wString Humidity }

	All the variables and arguments are case-insensitive.

	The variable wDayConditions_Long is always in English, the variable wDayPartConditions_Short is partly
	translated.

	The variables wConditionsSymbol, wMoonSymbol and wDayPartConditionsSymbol return the character corresponding
	to the symbol in the weather font.

output

	A file where the output of the script is stored. To make the script lightweight, the file is updated 
	if and only if new data are successfully downloaded, thus don't use /tmp/ to store this file - it could
	be deleted by the system.
	The script tries to download new data if and only if the current data are not for the current hour.

USAGE IN CONKY:

	To not to disturb Conky, it is preferable to run this script in a separate thread using the command
	$texeci. You can display the output file in Conky using the $execi or $execpi command and "cat".
	You have to use the $execpi variant whenever there are some Conky variables in the template.

	EXAMPLE:

	${texeci 300 perl ~/.conky/weather.pl EZXX0012 CZ M ~/.conky/weather.template ~/.conky/weather.conky}
	${execpi 240 cat ~/.conky/weather.conky}

=cut

use XML::Simple;

$code		= $ARGV[0];
$language	= $ARGV[1];
$unit 		= $ARGV[2];
$templatefile	= $ARGV[3];
$outputfile	= $ARGV[4];
$language	=~ tr/ENCZSK/enczsk/;
$unit		=~ tr/MS/ms/;

$xmlfile	= "$ENV{HOME}/.conky/weather_".$code.".xml";
$tempfile	= "$ENV{HOME}/.conky/weather_".$code.".tmp";


########################################################################################################

if(-e $xmlfile){
	my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
	($xmon, $xday, $xyear, $xhour) = lsup($xmlfile);
	$update = !($xmon == $mon + 1 && $xday == $mday && $xyear == $year - 100 && $xhour == $hour);
}
else {$update = TRUE};
if ($update) {
	open (THISFILE, $0);
	while (<THISFILE>) {
		if (m/^#\s/) {
			my @line = split /\s*#\s*|\s*\n/;
			shift @line;
			my $key = shift @line;
			$dictionary->{$key} = [@line];
		}
	}
	close (THISFILE);
	$code = &translate($code, 0);
	`wget -O $tempfile "http://xoap.weather.com/weather/local/$code?unit=$unit&dayf=10&dayd=10&cc=*"`;
	if (-s "$tempfile" > 0) {
		my ($tmon, $tday, $tyear, $thour) = lsup($tempfile);
		unless ($tmon == $xmon && $tday == $xday && $tyear == $xyear && $thour == $xhour) {
			`mv -f $tempfile $xmlfile`;
			&parse_template
		}
	}
}

########################################################################################################

sub lsup {
	open (XMLFILE, $_[0]);
	while (<XMLFILE>) {
		if (my ($xmon, $xday, $xyear, $xhour, $xdaypart) = m/^\s*\<lsup\>(\d*)\/(\d*)\/(\d*)\s(\d*):\d*\s([A|P])/) {
			if ($xhour   == 12 ) {$xhour  = 0 };
			if ($xdaypart eq "P") {$xhour += 12};
			return ($xmon, $xday, $xyear, $xhour);
			last 
		}
	};
	close (XMLFILE);
}

sub parse_template{
	my $temp = $/;
	undef $/;
	open (TEMPLATEFILE, $templatefile) || die "Can't open template.";
	$template = <TEMPLATEFILE>;
	close (TEMPLATEFILE);
	$/ = $temp;

	if    ($language eq "en") {$language_index = 0;	$time = sub {$_[0]};  $date = sub {$_[0]."/" .$_[1]. "/20".$_[2]}}
	elsif ($language eq "cz") {$language_index = 1; $time = \&time_en_24; $date = sub {$_[1].". ".$_[0].". 20".$_[2]}}
	elsif ($language eq "sk") {$language_index = 2; $time = \&time_en_24; $date = sub {$_[1].". ".$_[0].". 20".$_[2]}}
	                             $symbol_index = 3;

	$xml = new XML::Simple;
	$weather = $xml->XMLin($xmlfile);

	$template =~ s/\$\{\s*wString\s*(\w*)\s*\}/&translate($1, $language_index)/ieg;

	foreach $conky_key (wCode, wLatitude, wLongitude, wZone, wTemperature, wFlik, wPressure, wVisibility, wHumidity, wDewPoint,wWindSpeed,
			    wWindAzimuth, wSunset, wSunrise, wConditionsSymbol, wConditions, wMoonSymbol, wMoon, wWindDirection, wBarTendencySymbol, wBarTendency,
			    wUnitSpeed, wUnitDistance, wUnitTemperature, wUnitPressure, wUnitLatitude, wUnitLongitude, wObservationCountry, wObservation,
			    wLocation, wCountry, wSuplTime, wSuplDate, wUpdateTime, wUVIndex, wUVLevel){
		if ($template =~ m/\$\{\s*$conky_key\s*\}|\$$conky_key/i) {
			$template =~ s/\$\{\s*$conky_key\s*\}|\$$conky_key/&conky_value($conky_key)/ieg;
		}
	}

	for ($day = 0; $day < 10; $day++) {
		foreach $conky_key (wDayHighestTemperature, wDayLowestTemperature, wDayName_Short,wDayName, wDaySunset, wDaySunrise, wDayMonth, wDayDate) {
			if ($template =~ m/\$\{\s*$conky_key\s*$day\s*\}/i) {
				$template =~ s/\$\{\s*$conky_key\s*$day\s*\}/&conky_day($conky_key, $day)/ieg;
			};
		};
		for ($day_part = 0; $day_part < 2; $day_part++) {
			foreach $conky_key (wDayPartWindSpeed, wDayPartWindAzimuth, wDayPartWindDirection, wDayPartPrecipitation, wDayPartHumidity,
					    wDayPartConditionsSymbol, wDayPartConditions_Short, wDayPartConditions_Long, wDayPartConditions) {
				if ($template =~ m/\$\{\s*$conky_key\s*$day\s*$day_part\s*\}/i) {
					$template =~ s/\$\{\s*$conky_key\s*$day\s*$day_part\s*\}/&conky_day_part($conky_key, $day, $day_part)/eig;
				}
			}
		}
	};

	open (OUT, ">$outputfile") || die "Can't open output file";
	print OUT $template;
	close (OUT);
}

sub conky_day { # $_[0] key, $_[] day
	my $r = \$conky->{Day}[$_[1]]->{$_[0]};
	unless ($$r) {
		my $w = \$weather->{dayf}->{day}[$_[1]];
		if    ($_[0] eq "wDayHighestTemperature")	{$$r = $$w->{hi}}
		elsif ($_[0] eq "wDayLowestTemperature")	{$$r = $$w->{low}}
		elsif ($_[0] eq "wDayName_Short")		{$$r = &translate(substr($$w->{t},0,3), $language_index)}
		elsif ($_[0] eq "wDayName")			{$$r = &translate($$w->{t}, $language_index)}
		elsif ($_[0] eq "wDaySunset")			{$$r = &$time($$w->{suns})}
		elsif ($_[0] eq "wDaySunrise")			{$$r = &$time($$w->{sunr})}
		elsif ($_[0] eq "wDayMonth" || $_[0] eq "wDayDate") {
			my @temp = split " ", $weather->{dayf}->{day}[$_[1]]->{dt};
			$conky->{Day}[$_[1]]->{wDayMonth}	= &translate($temp[0], $language_index);
			$conky->{Day}[$_[1]]->{wDayDate}	= $temp[1];
		}
	}
	return $$r
}

sub conky_day_part { # $_[0] key, $_[1] day, $_[2] day part
	my $r = \$conky->{Day}[$_[1]]->{Part}[$_[2]]->{$_[0]};
	unless ($$r) {
		my $w = \$weather->{dayf}->{day}[$_[1]]->{part}[$_[2]];
		if    ($_[0] eq "wDayPartWindSpeed")		{$$r = $$w->{wind}->{s}}
		elsif ($_[0] eq "wDayPartWindAzimuth")		{$$r = $$w->{wind}->{d}}
		elsif ($_[0] eq "wDayPartPrecipitation")	{$$r = $$w->{ppcp}}
		elsif ($_[0] eq "wDayPartHumidity")		{$$r = $$w->{hmid}}
		elsif ($_[0] eq "wDayPartWindDirection")	{$$r = &translate($$w->{wind}->{t},	$language_index)}
		elsif ($_[0] eq "wDayPartConditionsSymbol")	{$$r = &translate($$w->{icon},		1)}
		elsif ($_[0] eq "wDayPartConditions")		{$$w->{t} =~ tr/A-Z/a-z/;
								 $$r = &translate($$w->{t},		$language_index)}
		elsif ($_[0] eq "wDayPartConditions_Short")	{$$w->{bt} =~ tr/A-Z/a-z/;
								 $$r = &translate($$w->{bt},		$language_index)}
		elsif ($_[0] eq "wDayPartConditions_Long")	{
			$w = \$weather->{dayd}->{day}[$_[1]]->{part};
			if (ref($$w) eq "ARRAY") {
				$$r = $weather->{dayd}->{day}[$_[1]]->{part}[$_[2]]->{t};
			}
			elsif   (($weather->{dayd}->{day}[$_[1]]->{part}->{p} eq "d" && $_[2] == 0)
                              || ($weather->{dayd}->{day}[$_[1]]->{part}->{p} eq "n" && $_[2] == 1)) {
				$$r = $weather->{dayd}->{day}[$_[1]]->{part}->{t}
			}
			else { $$r = ""};
		}
	}
	return $$r
}

sub conky_value { # $_[0] key
	my $r = \$conky->{$_[0]};
	unless ($$r) {
		if    ($_[0] eq "wCode")		{$$r = $code}
		elsif ($_[0] eq "wLatitude")		{$$r = $weather->{loc}->{lat}}
		elsif ($_[0] eq "wLongitude")		{$$r = $weather->{loc}->{lon}}
		elsif ($_[0] eq "wZone")		{$$r = $weather->{loc}->{zone}}
		elsif ($_[0] eq "wTemperature")		{$$r = $weather->{cc}->{tmp}}
		elsif ($_[0] eq "wFlik")		{$$r = $weather->{cc}->{flik}}
		elsif ($_[0] eq "wPressure")		{$$r = $weather->{cc}->{bar}->{r}}
		elsif ($_[0] eq "wVisibility")		{$$r = $weather->{cc}->{vis}}
		elsif ($_[0] eq "wHumidity")		{$$r = $weather->{cc}->{hmid}}
		elsif ($_[0] eq "wDewPoint")		{$$r = $weather->{cc}->{dewp}}
		elsif ($_[0] eq "wWindSpeed")		{$$r = $weather->{cc}->{wind}->{s}}
		elsif ($_[0] eq "wWindAzimuth")		{$$r = $weather->{cc}->{wind}->{d}}
		elsif ($_[0] eq "wUVIndex")		{$$r = $weather->{cc}->{uv}->{i}}
		elsif ($_[0] eq "wWindAzimuth")		{$$r = $weather->{cc}->{wind}->{d}}
		elsif ($_[0] eq "wUpdateTime")		{$$r = &$time($weather->{loc}->{tm})}
		elsif ($_[0] eq "wSunset")		{$$r = &$time($weather->{loc}->{suns})}
		elsif ($_[0] eq "wSunrise")		{$$r = &$time($weather->{loc}->{sunr})}
		elsif ($_[0] eq "wConditionsSymbol")	{$$r = &translate($weather->{cc}->{icon},	1)}
		elsif ($_[0] eq "wUVLevel")		{$$r = &translate($weather->{cc}->{uv}->{t},	$language_index)}
		elsif ($_[0] eq "wMoon")		{$$r = &translate($weather->{cc}->{moon}->{t},	$language_index)}
		elsif ($_[0] eq "wMoonSymbol")		{$$r = &translate($weather->{cc}->{moon}->{t},	$symbol_index)}
		elsif ($_[0] eq "wWindDirection")	{$$r = &translate($weather->{cc}->{wind}->{t},	$language_index)}
		elsif ($_[0] eq "wBarTendency")		{$$r = &translate($weather->{cc}->{bar}->{d},	$language_index)}
		elsif ($_[0] eq "wBarTendencySymbol")	{$$r = &translate($weather->{cc}->{bar}->{d},	$symbol_index)}
		elsif ($_[0] eq "wUnitSpeed")		{$$r = &translate($weather->{head}->{us},	$language_index)}
		elsif ($_[0] eq "wUnitDistance")	{$$r = &translate($weather->{head}->{ud},	$language_index)}
		elsif ($_[0] eq "wUnitTemperature")	{$$r = &translate($weather->{head}->{ut},	$language_index)}
		elsif ($_[0] eq "wUnitPressure")	{$$r = &translate($weather->{head}->{up},	$language_index)}
		elsif ($_[0] eq "wUnitLatitude")	{$$r = &translate("unit_latitude",		$language_index)}
		elsif ($_[0] eq "wUnitLongitude")	{$$r = &translate("unit_longitude",		$language_index)}
		elsif ($_[0] eq "wConditions")		{$weather->{cc}->{t} =~ tr/A-Z/a-z/;
							 $$r = &translate($weather->{cc}->{t},		$language_index)}
		elsif ($_[0] eq "wObservation" || $_[0] eq "wObservationCountry") {
			my @temp = split ", ", $weather->{cc}->{obst};
			$conky->{wObservation}		= &translate($temp[0], 1);
			$conky->{wObservationCountry}	= &translate($temp[1], $language_index);
		}
		elsif ($_[0] eq "wLocation" || $_[0] eq "wCountry") {
			my @temp = split ", ", $weather->{loc}->{dnam};
			$conky->{wLocation}	= &translate($temp[0], 1);
			$conky->{wCountry}	= &translate($temp[1], $language_index);
		}
		elsif ($_[0] eq "wSuplTime" || $_[0] eq "wSuplDate") {
			my @temp = split /\s|\//, $weather->{cc}->{lsup};
			$conky->{wSuplTime}	= &$time($temp[3]." ".$temp[4]);
			$conky->{wSuplDate}	= &$date($temp[0],$temp[1],$temp[2]);
		}
	}
	return $$r
}

sub translate {
	if ($dictionary->{$_[0]}) {return $dictionary->{$_[0]}[$_[1]]}
	else {return $_[0]}
}

sub time_en_24 {
	my @temp = split /\:|\s/, $_[0];
	if ($temp[0] == 12) {$temp[0] = 0};
	if ($temp[2] eq "PM") {$temp[0] += 12};
	return "$temp[0]".":"."$temp[1]";
}

########################################################################################################
## TRANSLATION TABLES
##
########################################################################################################

########################################################################################################
## COUNTRY
## value		# en			# cz			# sk
########################################################################################################
# Czech Republic	# Czech Republic	# Česká republika	# Česká republika
# Germany		# Germany		# Německo		# Nemecko
# Hungary		# Hungary		# Maďarsko		# Maďarsko
# Poland		# Poland		# Polsko		# Poľsko
# Slovakia		# Slovakia		# Slovensko		# Slovensko

########################################################################################################
## DAY
## value		# en			# cz			# sk
########################################################################################################
# Monday		# Monday		# Pondělí		# Pondelok
# Tuesday		# Tuesday		# Úterý			# Utorok
# Wednesday		# Wednesday		# Středa		# Streda
# Thursday		# Thursday		# Čtvrtek		# Štvrtok
# Friday		# Friday		# Pátek			# Piatok
# Saturday		# Saturday		# Sobota		# Sobota
# Sunday		# Sunday		# Neděle		# Nedeľa

########################################################################################################
## DAY_SHORT
## value		# en			# cz			# sk
########################################################################################################
# Mon			# Mon			# Po			# Po
# Tue			# Tue			# Út			# Ut
# Wed			# Wed			# St			# St
# Thu			# Thu			# Čt			# Št
# Fri			# Fri			# Pá			# Pi
# Sat			# Sat			# So			# So
# Sun			# Sun			# Ne			# Ne

########################################################################################################
## Month
## value		# en			# cz			# sk			# symbol
########################################################################################################
# Jan			# January		# Leden			# Január		# 1
# Feb			# February		# Únor			# Február		# 2
# Mar			# March			# Březen		# Marec			# 3
# Apr			# April			# Duben			# Apríl			# 4
# May			# May			# Květen		# Máj			# 5
# Jun			# June			# Červen		# Jún			# 6
# Jul			# July			# Červenec		# Júl			# 7
# Aug			# August		# Srpen			# August		# 8
# Sep			# September		# Září			# September		# 9
# Oct			# October		# Říjen			# Október		# 10
# Nov			# November		# Listopad		# November		# 11
# Dec			# December		# Prosinec		# December		# 12

########################################################################################################
## WIND
## value		# en			# cz			# sk
########################################################################################################
# N			# N			# S			# S
# E			# E			# V			# V
# S			# S			# J			# J
# W			# W			# Z			# Z
# NE			# NE			# SV			# SV
# SE			# SE			# JV			# JV
# SW			# SW			# JZ			# JZ
# NW			# NW			# SZ			# SZ
# NNE			# NNE			# SSV			# SSV
# ENE			# ENE			# VSV			# VSV
# ENE			# ENE			# VJV			# VJV
# SSE			# SSE			# JJV			# JJV
# NNW			# NNW			# SSZ			# SSZ
# WNW			# WNW			# ZSZ			# ZSZ
# WSW			# WSW			# ZJZ			# ZJZ
# SSW			# SSW			# JJZ			# JJZ
# VAR			# variable		# proměnlivý		# premenlivý

########################################################################################################
## UNIT
## space-separated units start with a hard space
## value		# en			# cz			# sk
#########################################################################################################
# C			#  °C			#  °C			#  °C
# km			#  km			#  km			#  km
# km/h			#  km/h			#  km/h			#  km/h
# mb			#  mb			#  hPa			#  hPa
# mm			#  mm			#  mm			#  mm
# F			#  °F			#  °F			#  °F
# mi			#  mi			#  mi			#  mi
# mph			#  mph			#  mph			#  mph
# in			#  in			#  in			#  in
# unit_latitude		# N			#  s. š.		#  s. š.
# unit_longitude	# E			#  v. d.		#  v. d.

########################################################################################################
## PREASURE
## value		# en			# cz			# sk			# symbol
########################################################################################################
# rising		# rising		# stoupající		# stúpajúci		# ↑
# falling		# falling		# klesající		# klesajúci		# ↓
# steady		# steady		# setrvalý		# stály			# =

########################################################################################################
## LUNAR PHASE 
## value		# en			# cz			# sk			# symbol
########################################################################################################
# New			# New			# Nov			# Nov			# 9
# Waxing Crescent	# Waxing Crescent	# Dorůstající srpek	# Dorastajúci kosák	# 7
# First Quarter		# First Quarter		# První čtvrť		# Prvá štvrť		# 0
# Waxing Gibbous	# Waxing Gibbous	# Dorůstající měsíc	# Dorastajúci mesiac	# 3
# Full			# Full			# Úplněk		# Spln			# 1
# Waning Gibbous	# Waning Gibbous	# Couvající měsíc	# Cúvajúci mesiac	# 3	# (left <-> right)
# Last Quarter		# Last Quarter		# Poslední čvrť		# Posledná štvrť	# 0	# (left <-> right)
# Third Quarter		# Third Quarter		# Poslední čvrť		# Posledná štvrť	# 0	# (left <-> right)
# Waning Crescent	# Waning Crescent	# Ubývající srpek	# Ubúdajúci kosák	# 7	# (left <-> right)

########################################################################################################
## UV Index
## value		# en			# cz			# sk			# symbol
########################################################################################################
# Extreme		# extrem		# extrémní		# extrémny
# Very high		# very high		# velmi vysoký		# veľmi vysoký
# High			# high			# vysoký		# vysoký
# Moderate		# moderate		# střední		# stredný
# Low			# low			# nízký			# nízky

########################################################################################################
## STRING
## value		# en			# cz			# sk			# symbol
########################################################################################################
# weather		# Weather		# Počasí		# Počasie
# forecast		# Forecast		# Předpověď		# Predpoveď
# as_of			# as of			# Stav k		# Stav k
# update		# Update		# Update		# Update
# pressure		# Pressure		# Tlak			# Tlak
# wind			# Wind			# Vítr			# Vietor
# dew_point		# Dew point		# Rosný bod		# Rosný bod
# visibility		# Visibility		# Viditelnost		# Viditeľnosť
# sunrise		# Sunrise		# Východ		# Východ
# sunset		# Sunset		# Západ			# Západ
# moon			# Moon			# Měsíc			# Mesiac
# humidity		# Humidity		# Vlhkost		# Vlhkosť
# uv			# UV index		# UV index		# UV index

########################################################################################################
## CONDITIONS
## value			# en				# cz				# sk
########################################################################################################
# blowing dust			# Blowing dust			# Poletující prach		# Poletujúci prach
# blowing dust and windy	# Blowing dust and windy	# Poletující prach a větrno	# Poletujúci prach a veterno
# blowing snow			# Blowing snow			# Poletující sníh		# Poletujúci snieh
# blowing snow and windy	# Blowing snow and windy	# Poletující sníh a větrno	# Poletujúci snieh a veterno
# clear				# Clear				# Jasno				# Jasno
# clear and windy		# Clear and windy		# Jasno a větrno		# Jasno a veterno
# cloudy			# Cloudy			# Oblačno			# Oblačno
# cloudy and windy		# Cloudy and windy		# Oblačno a větrno		# Oblačno a veterno
# drifting snow			# Drifting snow			# Vanoucí sníh 			# Vanúci snieh
# drizzle			# Drizzle			# Mrholení			# Mrholenie
# fair				# Fair				# Jasno				# Jasno
# fair and windy		# Fair and windy		# Jasno a větrno		# Jasno a veterno
# fog				# Fog				# Mlha				# Hmla
# fog and windy			# Fog and windy			# Mlha a větrno			# Hmla a veterno
# haze				# Haze				# Opar				# Opar
# haze and windy		# Haze and windy		# Opar a větrno			# Opar a veterno
# heavy drizzle			# Heavy drizzle			# Silné mrholení		# Silné mrholenie
# heavy rain			# Heavy rain			# Silný déšť			# Silný dážď
# heavy rain and windy		# Heavy rain and windy		# Silný déšť a větrno		# Silný dážď a veterno
# heavy rain shower		# Heavy rain shower		# Silné dešťové přeháňky	# Silné dažďové prehánky
# heavy rain shower and windy	# Heavy rain shower and windy	# Silné dešťové přeháňky, větrno# Silné dažďové prehánky a veterno
# heavy snow			# Heavy snow			# Silné sněžení			# Silné sneženie
# heavy snow and windy		# Heavy snow and windy		# Silné sněžení a větrno	# Silné sneženie a veterno
# heavy snow shower		# Heavy snow shower		# Silné sněhové přeháňky	# Silné snehové prehánky
# heavy t-storm			# Heavy t-storm			# Silná bouřka			# Silná búrka
# heavy t-storm and windy	# Heavy t-storm and windy	# Silná bouřka a větrno		# Silná búrka a větrno
# light drizzle			# Light drizzle			# Slabé mrholení		# Ľahké mrholenie
# light drizzle and windy	# Light drizzle and windy	# Slabé mrholení a větrno	# Ľahké mrholenie a veterno
# light freezing drizzle	# Light freezing drizzle	# Slabé mrznoucí mrholení	# Ľahké mrznúce mrholenie
# light freezing drizzle and fog# Light freezing drizzle and fog#Slabé mrznoucí mrholení, větrno# Ľahké mrznúce mrholenie a veterno
# light freezing rain		# Light freezing rain		# Lehký mrznoucí déšť		# Ľahký mrznúci dážď
# light rain			# Light rain			# Lehký déšť			# Ľahký dážď
# light rain shower		# Light rain shower		# Lehké dešťové přeháňky	# Ľahké dažďové prehánky
# light rain shower and windy	# Light rain shower and windy	# Lehké dešťové přeháňky, větrno# Ľahké dažďové prehánky a veterno
# light rain and fog		# Light rain and fog		# Lehký déšť a mlha		# Ľahký dážď a hmla
# light rain and freezing rain	# Light rain and freezing rain	# Lekký déšť a mrznoucí déšť	# Ľahký dážď a mrznúci dážď
# light rain with thunder	# Light rain with thunder	# Lehký déšť s hřměním		# Ľahký dážď s hrmením
# light rain and windy		# Light rain and windy		# Lehký déšť a větrno		# Ľahký dážď a veterno
# light snow			# Light snow			# Lehké sněžení			# Ľahké sneženie
# light snow grains		# Light snow grains		# Slabé zrnité sněžení		# Ľahké zrnité sneženie
# light snow shower		# Light snow shower		# Lehké sněhové přeháňky	# Ľahké snehové prehánky
# light snow shower and windy	# Light snow shower and windy	# Lehké sněhové přeháňky, větrno# Ľahké snehové prehánky a veterno
# light snow and sleet		# Light snow and sleet		# Lehké sněžení a plískanice	# Ľahké sneženie a plušť
# light snow and windy		# Light snow and windy		# Lehké sněžení a větrno	# Ľahké sneženie a veterno
# mist				# Mist				# Mlha				# Hmla
# mostly cloudy			# Mostly cloudy			# Převážně oblačno		# Prevažne oblačno
# mostly cloudy and windy	# Mostly cloudy and windy	# Převážně oblačno a větrno	# Prevažne oblačno a veterno
# partial fog			# Partial fog			# Částečná mlha			# Čiastočná hmla
# partly cloudy			# Partly cloudy			# Polojasno			# Čiastočne oblačno
# partly cloudy and windy	# Partly cloudy and windy	# Polojasno a větrno		# Čiastočne oblačno a veterno
# patches of fog		# Patches of fog		# Mlhové pole			# Hmlové pole
# rain				# Rain				# Déšť				# Dážď
# rain and sleet		# Rain and sleet		# Déšť a plískanice		# Dážď a pľušť
# rain and snow			# Rain and snow			# Déšť se sněhem		# Dážď so snehom
# rain shower			# Rain shower			# Dešťové přeháňky		# Dažďové prehánky
# rain shower and windy		# Rain shower and windy		# Dešťové přeháňky a větrno	# Dažďové prehánky a veterno
# rain and fog			# Rain and fog			# Déšť a mlha			# Dážd a hmla
# rain and freezing rain	# Rain and freezing rain	# Déšť a mrznoucí déšť		# Dážď a mrznúci dážď
# rain and windy		# Rain and windy		# Déšť a větrno			# Dážď a veterno
# sand				# Sand				# Písek				# Piesok
# sand and windy		# Sand and windy		# Písek a větrno		# Piesok a veterno
# shallow fog			# Shallow fog			# Slabá mlha			# Ľahká hmla
# showers in the vicinity	# Showers in the vicinity	# Místy přeháňky		# Miestami prehánky
# sleet				# Sleet				# Plískanice			# Pľušť
# smoke				# Smoke				# Kouř				# Dym
# snow				# Snow				# Sněžení			# Sneženie
# snow and fog			# Snow and fog			# Sněžení a mlha		# Sneženie a hmla
# snow and freezing rain	# Snow and freezing rain	# Mrznoucí déšť se sněhem	# Mrznúci dážď zo snehom
# snow grains			# Snow grains			# Zrnité sněžení		# Zrnité sneženie
# snow showers			# Snow showers			# Sněhové přeháňky		# Snehové prehánky
# snow and windy and fog	# Snow and windy and fog	# Sněžení, větrno a mlha	# Sneženie, veterno a hmla
# squalls			# Squalls			# Poryvy			# Poryvy
# squalls and windy		# Squalls and windy		# Poryvy a větrno		# Poryvy a veterno
# sunny				# Sunny				# Slunečno			# Slnečno
# sunny and windy		# Sunny and windy		# Slnečno a větrno		# Slnečno a veterno
# t-storm			# T-Storm			# Bouřka			# Búrka
# t-storm and windy		# T-Storm and windy		# Bouřka a větrno		# Búrka a veterno
# thunder			# Thunder			# Hřmění			# Hrmenie
# thunder and wintry mix	# Thunder and wintry mix	# Bouřka a plískanice		# Búrka a pľušť
# thunder in the vicinity	# Thunder in the vicinity	# Místy hřmění			# Miestami hrmenie
# unknown precip		# Unknown precip		# Neznámé srážky		# Neznáme zrážky
# widespread dust		# Widespread dust		# Prašno			# Prašno
# widespread dust and windy	# Widespread dust and windy	# Prašno a větrno		# Prašno a veterno
# wintry mix			# Wintry mix			# Proměnlivé zimní počasí	# Premenlivé zimné počasie

########################################################################################################
##			    ICONS
## Nr.	# Yahoo description		# symbol
########################################################################################################
# 0	# tornado			# i
# 1	# tropical storm		# h
# 2	# hurricane			# h
# 3	# severe thunderstorms		# i
# 4	# thunderstorms			# i
# 5	# mixed rain and snow		# k
# 6	# mixed rain and sleet		# h
# 7	# mixed snow and sleet		# k
# 8	# freezing drizzle		# g
# 9	# drizzle			# g
# 10	# freezing rain			# h
# 11	# showers			# g
# 12	# showers			# h
# 13	# snow flurries			# j
# 14	# light snow showers		# k
# 15	# blowing snow			# j
# 16	# snow				# k
# 17	# hail				# i
# 18	# sleet				# h
# 19	# dust				# v
# 20	# foggy				# v
# 21	# haze				# v
# 22	# smoky				# v
# 23	# blustery			# w
# 24	# windy				# w
# 25	# cold				# j
# 26	# cloudy			# d
# 27	# mostly cloudy (night)		# d
# 28	# mostly cloudy (day)		# c
# 29	# partly cloudy (night)		# b
# 30	# partly cloudy (day)		# b
# 31	# clear (night)			# 1
# 32	# sunny				# a
# 33	# fair (night)			# 1
# 34	# fair (day)			# b
# 35	# mixed rain and hail		# i
# 36	# hot				# l
# 37	# isolated thunderstorms	# f
# 38	# scattered thunderstorms	# f
# 39	# scattered thunderstorms	# h
# 40	# scattered showers		# h
# 41	# heavy snow			# k
# 42	# scattered snow showers	# k
# 43	# heavy snow			# k
# 44	# partly cloudy			# b
# 45	# thundershowers		# h
# 46	# snow showers			# k
# 47	# isolated thundershowers	# g
# na	# not available			# ~

########################################################################################################
## Czech Republic 
## loc dnam		# code		# Local name
########################################################################################################
# Beroun		# EZXX0001	# Beroun
# Breclav		# EZXX0035	# Břeclav
# Brno			# EZXX0002	# Brno
# Budweis		# EZXX0030	# České Budějovice
# Cervena		# EZXX0027	# Červená hora
# Cesky Tesin		# EZXX0003	# Český Těšín
# Cheb			# EZXX0017	# Cheb
# Chomutov		# EZXX0044	# Chomutov
# Churanov		# EZXX0019	# Churáňov
# Dormazlice		# EZXX0040	# Domažlice
# Frydek		# EZXX0004	# Frýdek
# Hodonin		# EZXX0036	# Hodonín
# Holesov		# EZXX0028	# Holešov
# Jaromer		# EZXX0032	# Jaroměř
# Jesenik 		# EZXX0037	# Jeseník
# Jicin			# EZXX0031	# Jičín
# Jindrichuv Hradec	# EZXX0039	# Jindřichův Hradec
# Karlovy Vary		# EZXX0045	# Karlovy Hory
# Karvina		# EZXX0005	# Karviná
# Kladno		# EZXX0006	# Kladno
# Klatovy		# EZXX0041	# Klatovy
# Kocelovice		# EZXX0021	# Kocelovice
# Kolin			# EZXX0007	# Kolín
# Kostelni Myslova	# EZXX0024	# Kostelní Myslová
# Liberec		# EZXX0023	# Liberec
# Lysa Hora		# EZXX0029	# Lysá hora
# Milesovka		# EZXX0020	# Milešovka
# Nachod		# EZXX0047	# Náchod
# Olomouc		# EZXX0038	# Olomouc
# Opava			# EZXX0008	# Opava
# Ostrava		# EZXX0009	# Ostrava
# Pardubice		# EZXX0034	# Pardubice
# Pilsen		# EZXX0010	# Plzeň
# Pisek			# EZXX0011	# Písek
# Prague		# EZXX0012	# Praha
# Praha-Libus		# EZXX0022	# Praha-Libuš
# Pribyslav		# EZXX0025	# Přibyslav
# Primda		# EZXX0018	# Přimda
# Prostejov		# EZXX0049	# Prostějov
# Rosice		# EZXX0013	# Rosice
# Slavkov u Brna	# EZXX0014	# Slavkov u Brna
# Strakonice		# EZXX0042	# Strakonice
# Sumperk		# EZXX0048	# Šumperk
# Tabor			# EZXX0015	# Tábor
# Trebic		# EZXX0033	# Třebíč
# Trutnov		# EZXX0046	# Trutnov
# Turnov		# EZXX0043	# Turnov
# Usti Nad Orlici	# EZXX0026	# Ústí nad Orlicí
# Usti nad Labem	# EZXX0016	# Ústí nad Labem

########################################################################################################
## Slovakia 
## loc dnam		# code		# Local name
########################################################################################################
# Banska Stiavnica	# LOXX0013	# Banská Štiavnica
# Bardejov		# LOXX0017	# Bardejov
# Bratislava		# LOXX0001	# Bratislava
# Brezno		# LOXX0028	# Brezno
# Cadca			# LOXX0019	# Čadca
# Handlova		# LOXX0012	# Handlová
# Humenne		# LOXX0025	# Humenné
# Ivanka pri Dunaji	# LOXX0002	# Ivanka pri Dunaji
# Kosice		# LOXX0003	# Košice
# Levice 		# LOXX0022	# Levice
# Lucenec		# LOXX0024	# Lučenec
# Martin		# LOXX0010	# Martin
# Nitra			# LOXX0021	# Nitra
# Nove Zamky		# LOXX0004	# Nové Zámky
# Piestany		# LOXX0008	# Piešťany
# Poprad		# LOXX0005	# Poprad
# Prievidza		# LOXX0011	# Prievidza
# Rimavska Sobota	# LOXX0015	# Rimavská Sobota
# Roznava		# LOXX0014	# Rožňava
# Senec			# LOXX0006	# Senec
# Senica		# LOXX0020	# Senica
# Sliac			# LOXX0009	# Sliač
# Snina			# LOXX0018	# Snina
# Stropkov		# LOXX0016	# Stropkov
# Topolcany		# LOXX0023	# Topoľčany
# Trencin		# LOXX0027	# Trenčín
# Trnava		# LOXX0007	# Trnava
# Zilina		# LOXX0026	# Žilina
